@@ -55,16 +55,10 @@ class VideoGameSession(ScrobblableMixin):
         event_dict = {
             "title": data_dict.get("Name"),
             "event_type": data_dict.get("ItemType"),
-            "home_team": home_team,
-            "away_team": away_team,
             "start": data_dict['Start'],
-            "league": league,
             "run_time_ticks": data_dict.get("RunTimeTicks"),
             "run_time": data_dict.get("RunTime", ""),
         }
         event, _created = cls.objects.get_or_create(**event_dict)
 
         return event
-
-
-#!/usr/bin/env python3
